import React, { useState, useEffect,useMemo} from 'react';
import {
  scaleTime,
  extent,
  scaleLog,
  max,
  min,
  line,
} from 'd3';
import { XAxis } from './XAxis';
import { YAxis } from './YAxis';
const xValue = (d) => d.date;
const yValue = (d) => d.deathTotal;

const margin = {
  left: 100,
  right: 80,
  top: 40,
  bottom: 60,
};
export const LineChart = ({ data, width, height }) => {
  const innerWidth = width - (margin.left + margin.right);
  const innerHeight = height - (margin.top + margin.bottom);
  const allData = useMemo(
    () =>
      data.reduce(
        (accumulator, countryTimeseries) =>
          accumulator.concat(countryTimeseries),
        []
      ),
    [data]
  );


  const epsilon = 1;

  const xScale = useMemo(
    () => scaleTime().domain(extent(allData, xValue)).range([0, innerWidth]),
    [allData, xValue]
  );

  const yScale = useMemo(
    () =>
      scaleLog()
        .domain([epsilon, max(allData, yValue)])
        .range([innerHeight, 0]),
    [epsilon, allData, yValue]
  );

  const lineGenerator = useMemo(
    () =>
      line()
        .x((d) => xScale(xValue(d)))
        .y((d) => yScale(epsilon + yValue(d))),
    [xScale, xValue, yScale, yValue, epsilon]
  );


  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left},${margin.top})`}
      >
        <XAxis xScale={xScale} innerHeight={innerHeight} />
        <YAxis yScale={yScale} innerWidth={innerWidth} />
             {data.map((countryTimeseries, index) => {
    
          return (
            <path 
              stroke={`rgb(${Math.random()*255},${Math.random()*255},${Math.random()*255})`}
              d={lineGenerator(countryTimeseries)}
            />
          );
        })}

        <text transform={`translate(${innerWidth / 3},0)`}>
          Global CoronaVirus Deaths Over Time by Country
        </text>
        <text
          text-anchor="middle"
          transform={`translate(-70,${
            innerHeight / 2
          }) rotate(-90)`}
        >
          Comulative Deaths
        </text>
        <text
          alignment-baseline="hanging"
          transform={`translate(${innerWidth / 2},${
            innerHeight + 30
          })`}
        >
          Time
        </text>
      </g>
    </svg>
  );
};
